% Compute the element load vectors corresponding to surface heat transfer.
% Return an array of them so they may be assembled.
%    Call as
% evs = surface_transfer_loads(feb, geom, temp, amb)
%     geom=geometry field
%     temp=temperature field
%     amb = ambient temperature field
%
function evs = surface_transfer_loads (self, geom, temp, amb)
    gcells = get(self.feblock,'gcells');
    ngcells = length(gcells);
    nfens = get(gcells(1),'nfens');
    dim = get(geom,'dim');
    % Pre-allocate the element matrices
    evs(1:ngcells) = deal(elevec);
    % Integration rule
    integration_rule = get(self.feblock, 'integration_rule');
    pc = get(integration_rule, 'param_coords');
    w  = get(integration_rule, 'weights');
    npts_per_gcell = get(integration_rule, 'npts');
    % surface transfer coefficient
    h = self.surface_transfer;
    % Now loop over all gcells in the block
    for i=1:ngcells
        conn = get(gcells(i), 'conn'); % connectivity
        pT = gather(amb, conn, 'prescribed_values');
        if norm (pT) ~= 0
            x = gather(geom, conn, 'values', 'noreshape'); % node coord
            He = zeros(nfens); % element matrix
            % Loop over all integration points
            for j=1:npts_per_gcell
                N = Nmat(gcells(i), pc(j,:));
                Nder = Ndermat_param (gcells(i), pc(j,:));
                detJ = Jacobian(gcells(i),x'*Nder);
                He = He + h*N*N' * detJ * w(j);
            end
            evs(i) = set(evs(i), 'vec', He*pT);
            evs(i) = set(evs(i), 'eqnums', ...
                gather(temp, conn, 'eqnums'));
        end
    end
    return;
end
